package com.link.core.util;

import com.alibaba.fastjson.JSONArray;
import com.link.base.basic.model.ListOfValue;
import com.link.base.basic.service.BasicCommonService;
import com.link.core.basic.model.BasicModel;
import com.link.core.util.entry.EntityBuilder;
import com.link.core.util.redisclient.LinkRedisClient;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;
import org.springframework.util.CollectionUtils;

public class CommonUtils {
   private static final String[] stayFields = new String[]{"id", "type", "val", "name", "parentId", "parentType", "parentVal", "parentName", "seq"};
   public static final String LOV_CACHE_PREFIX = "LOV_CACHE_";
   private static final int EXPIRE_TIME = 86400;

   public static List<ListOfValue> getAllLovByType(String type) throws Exception {
      LinkRedisClient linkRedisClient = null;

      try {
         linkRedisClient = RedisUtil.getJedis();
         String corpId = Objects.isNull(UserUtil.getUser()) ? "0" : UserUtil.getUser().getCorpid() + "";
         String lovStr = linkRedisClient.get("LOV_CACHE_" + type + "_" + corpId);
         if (StringUtils.isBlank(lovStr)) {
            List<ListOfValue> list = queryAndCacheLov(type, linkRedisClient);
            return (List)(CollectionUtils.isEmpty(list) ? new ArrayList() : list);
         } else {
            return JSONArray.parseArray(lovStr, ListOfValue.class);
         }
      } catch (Exception var5) {
         Exception e = var5;
         throw e;
      }
   }

   public static String getLovName(String type, String value) throws Exception {
      LinkRedisClient linkRedisClient = null;

      String var8;
      try {
         linkRedisClient = RedisUtil.getJedis();
         String corpId = Objects.isNull(UserUtil.getUser()) ? "0" : UserUtil.getUser().getCorpid() + "";
         String key = "LOV_CACHE_" + type + "_" + corpId;
         String lovStr = linkRedisClient.get(key);
         List list;
         List names;
         if (StringUtils.isBlank(lovStr)) {
            list = queryAndCacheLov(type, linkRedisClient);
            list = (List)list.stream().filter((s) -> {
               return s.getVal().equals(value);
            }).collect(Collectors.toList());
            if (CollectionUtils.isEmpty(list)) {
               names = null;
               return names;
            }

            String var15 = ((ListOfValue)list.get(0)).getName();
            return var15;
         }

         list = JSONArray.parseArray(lovStr, ListOfValue.class);
         names = (List)list.stream().filter((s) -> {
            return s.getVal().equals(value);
         }).map((s) -> {
            return s.getName();
         }).collect(Collectors.toList());
         var8 = CollectionUtils.isEmpty(names) ? null : (String)names.get(0);
      } catch (Exception var12) {
         Exception e = var12;
         throw e;
      } finally {
         RedisUtil.returnResource(linkRedisClient);
      }

      return var8;
   }

   public static ListOfValue getLovInfo(String type, String value) throws Exception {
      LinkRedisClient linkRedisClient = null;

      ListOfValue var8;
      try {
         linkRedisClient = RedisUtil.getJedis();
         String corpId = Objects.isNull(UserUtil.getUser()) ? "0" : UserUtil.getUser().getCorpid() + "";
         String key = "LOV_CACHE_" + type + "_" + corpId;
         String lovStr = linkRedisClient.get(key);
         List list;
         List lovs;
         if (StringUtils.isBlank(lovStr)) {
            list = queryAndCacheLov(type, linkRedisClient);
            list = (List)list.stream().filter((s) -> {
               return s.getVal().equals(value);
            }).collect(Collectors.toList());
            if (CollectionUtils.isEmpty(list)) {
               lovs = null;
               return lovs;
            }

            ListOfValue var15 = (ListOfValue)list.get(0);
            return var15;
         }

         list = JSONArray.parseArray(lovStr, ListOfValue.class);
         lovs = (List)list.stream().filter((s) -> {
            return s.getVal().equals(value);
         }).collect(Collectors.toList());
         var8 = CollectionUtils.isEmpty(lovs) ? null : (ListOfValue)lovs.get(0);
      } catch (Exception var12) {
         Exception e = var12;
         throw e;
      } finally {
         RedisUtil.returnResource(linkRedisClient);
      }

      return var8;
   }

   private static List<ListOfValue> queryAndCacheLov(String type, LinkRedisClient linkRedisClient) throws Exception {
      String corpId = Objects.isNull(UserUtil.getUser()) ? "0" : UserUtil.getUser().getCorpid() + "";
      String key = "LOV_CACHE_" + type + "_" + corpId;
      ListOfValue entity = (ListOfValue)EntityBuilder.builder(ListOfValue::new).with(ListOfValue::setType, type.toUpperCase()).with(ListOfValue::setActiveFlag, "Y").with(BasicModel::setPageFlag, false).build();
      BasicCommonService basicCommonService = (BasicCommonService)SpringUtil.getBean(BasicCommonService.class);
      List<ListOfValue> list = basicCommonService.queryByExamplePage(entity);
      String json = JsonUtil.listToStringIncludeArrays(list, stayFields);
      linkRedisClient.set(key, json);
      linkRedisClient.expire(key, 86400);
      return list;
   }
}
